@@ -66,7 +66,7 @@ GST_DEBUG_CATEGORY_STATIC (pygst_debug);
 #define GST_CAT_DEFAULT pygst_debug
 
 static PyObject *
-gi_gst_get_type (const gchar * type_name)
+gi_gst_get_type (gchar * type_name)
 {
   PyObject *module, *dict;
 
@@ -137,13 +137,21 @@ static PyObject *
 gi_gst_int_range_from_value (const GValue * value)
 {
   gint min, max, step;
+  PyObject *int_range_type, *int_range, *range;
 
   min = gst_value_get_int_range_min (value);
   max = gst_value_get_int_range_max (value);
   step = gst_value_get_int_range_step (value);
 
-  return PyObject_CallFunction ((PyObject *) & PyRange_Type, "iii",
+  int_range_type = gi_gst_get_type ("IntRange");
+  range = PyObject_CallFunction ((PyObject *) & PyRange_Type, "iii",
       min, max, step);
+  int_range = PyObject_CallFunction (int_range_type, "O", range);
+
+  Py_DECREF (int_range_type);
+  Py_DECREF (range);
+
+  return int_range;
 }
 
 static int
@@ -182,13 +190,21 @@ static PyObject *
 gi_gst_int64_range_from_value (const GValue * value)
 {
   gint64 min, max, step;
+  PyObject *int64_range_type, *int64_range, *range;
 
   min = gst_value_get_int64_range_min (value);
   max = gst_value_get_int64_range_max (value);
   step = gst_value_get_int64_range_step (value);
 
-  return PyObject_CallFunction ((PyObject *) & PyRange_Type, "LLL",
+  range = PyObject_CallFunction ((PyObject *) & PyRange_Type, "LLL",
       min, max, step);
+  int64_range_type = gi_gst_get_type ("Int64Range");
+  int64_range = PyObject_CallFunction (int64_range_type, "O", range);
+
+  Py_DECREF (int64_range_type);
+  Py_DECREF (range);
+
+  return int64_range;
 }
 
 static int
@@ -384,6 +400,35 @@ fail:
   return -1;
 }
 
+static PyObject *
+gi_gst_bitmask_from_value (const GValue * value)
+{
+  PyObject *val, *bitmask_type;
+
+  bitmask_type = gi_gst_get_type ("Bitmask");
+  val = PyObject_CallFunction (bitmask_type, "L",
+      gst_value_get_bitmask (value));
+  Py_DECREF (bitmask_type);
+
+  return val;
+}
+
+static int
+gi_gst_bitmask_to_value (GValue * value, PyObject * object)
+{
+  PyObject *v = PyObject_GetAttrString (object, "v");
+  if (v == NULL)
+    goto fail;
+
+  gst_value_set_bitmask (value, PyLong_AsLong (v));
+
+  return 0;
+
+fail:
+  PyErr_SetString (PyExc_KeyError, "Object is not compatible with Gst.Bitmask");
+  return -1;
+}
+
 static PyObject *
 gi_gst_list_from_value (const GValue * value)
 {
@@ -471,9 +516,9 @@ gi_gst_register_types (PyObject * d)
       gi_gst_date_time_from_value, gi_gst_date_time_to_value);
   pyg_register_gtype_custom (GST_TYPE_FLAG_SET,
       gi_gst_flag_set_from_value, gi_gst_flag_set_to_value);
+#endif
   pyg_register_gtype_custom (GST_TYPE_BITMASK,
       gi_gst_bitmask_from_value, gi_gst_bitmask_to_value);
-#endif
 }
 
 static int
